@@ -11,7 +11,7 @@ package Pod::Usage;
 use strict;
 
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '1.61';  ## Current version of this package
+$VERSION = '1.65';  ## Current version of this package
 require  5.006;    ## requires this Perl version or later
 
 #use diagnostics;
@@ -93,7 +93,7 @@ sub pod2usage {
     ## Default the input file
     $opts{'-input'} = $0  unless (defined $opts{'-input'});
 
-    ## Look up input file in path if it doesnt exist.
+    ## Look up input file in path if it doesn't exist.
     unless ((ref $opts{'-input'}) || (-e $opts{'-input'})) {
         my $basename = $opts{'-input'};
         my $pathsep = ($^O =~ /^(?:dos|os2|MSWin32)$/i) ? ';'
@@ -263,10 +263,13 @@ sub select {
 
 # Override Pod::Text->seq_i to return just "arg", not "*arg*".
 sub seq_i { return $_[1] }
+# Override Pod::Text->cmd_i to return just "arg", not "*arg*".
+# newer version based on Pod::Simple
+sub cmd_i { return $_[2] }
 
 # This overrides the Pod::Text method to do something very akin to what
 # Pod::Select did as well as the work done below by preprocess_paragraph.
-# Note that the below is very, very specific to Pod::Text.
+# Note that the below is very, very specific to Pod::Text and Pod::Simple.
 sub _handle_element_end {
     my ($self, $element) = @_;
     if ($element eq 'head1') {
@@ -278,6 +281,8 @@ sub _handle_element_end {
         my $idx = $1 - 1;
         $self->{USAGE_HEADINGS} = [] unless($self->{USAGE_HEADINGS});
         $self->{USAGE_HEADINGS}->[$idx] = $$self{PENDING}[-1][1];
+        # we have to get rid of the lower headings
+        splice(@{$self->{USAGE_HEADINGS}},$idx+1);
     }
     if ($element =~ /^head\d+$/) {
         $$self{USAGE_SKIPPING} = 1;
@@ -312,7 +317,7 @@ sub _handle_element_end {
             $$self{PENDING}[-1][1] = $_;
         }
     }
-    if ($$self{USAGE_SKIPPING} && $element !~ m/^over-/) {
+    if ($$self{USAGE_SKIPPING} && $element !~ m/^over-|^[BCFI]$/) {
         pop @{ $$self{PENDING} };
     } else {
         $self->SUPER::_handle_element_end($element);
@@ -341,7 +346,7 @@ sub preprocess_paragraph {
     my $self = shift;
     local $_ = shift;
     my $line = shift;
-    ## See if this is a heading and we arent printing the entire manpage.
+    ## See if this is a heading and we aren't printing the entire manpage.
     if (($self->{USAGE_OPTIONS}->{-verbose} < 2) && /^=head/) {
         ## Change the title of the SYNOPSIS section to USAGE
         s/^=head1\s+SYNOPSIS\s*$/=head1 USAGE/;
@@ -360,7 +365,7 @@ __END__
 
 =head1 NAME
 
-Pod::Usage, pod2usage() - print a usage message from embedded pod documentation
+Pod::Usage - print a usage message from embedded pod documentation
 
 =head1 SYNOPSIS
 
@@ -594,13 +599,15 @@ use them by default if you don't expressly tell it to do otherwise.  The
 ability of B<pod2usage()> to accept a single number or a string makes it
 convenient to use as an innocent looking error message handling function:
 
+    use strict;
     use Pod::Usage;
     use Getopt::Long;
 
     ## Parse options
-    GetOptions("help", "man", "flag1")  ||  pod2usage(2);
-    pod2usage(1)  if ($opt_help);
-    pod2usage(-verbose => 2)  if ($opt_man);
+    my %opt;
+    GetOptions(\%opt, "help|?", "man", "flag1")  ||  pod2usage(2);
+    pod2usage(1)  if ($opt{help});
+    pod2usage(-exitval => 0, -verbose => 2)  if ($opt{man});
 
     ## Check for too many filenames
     pod2usage("$0: Too many files given.\n")  if (@ARGV > 1);
@@ -609,23 +616,35 @@ Some user's however may feel that the above "economy of expression" is
 not particularly readable nor consistent and may instead choose to do
 something more like the following:
 
-    use Pod::Usage;
-    use Getopt::Long;
+    use strict;
+    use Pod::Usage qw(pod2usage);
+    use Getopt::Long qw(GetOptions);
 
     ## Parse options
-    GetOptions("help", "man", "flag1")  ||  pod2usage(-verbose => 0);
-    pod2usage(-verbose => 1)  if ($opt_help);
-    pod2usage(-verbose => 2)  if ($opt_man);
+    my %opt;
+    GetOptions(\%opt, "help|?", "man", "flag1")  ||
+      pod2usage(-verbose => 0);
+
+    pod2usage(-verbose => 1)  if ($opt{help});
+    pod2usage(-verbose => 2)  if ($opt{man});
 
     ## Check for too many filenames
     pod2usage(-verbose => 2, -message => "$0: Too many files given.\n")
-        if (@ARGV > 1);
+      if (@ARGV > 1);
+
 
 As with all things in Perl, I<there's more than one way to do it>, and
 B<pod2usage()> adheres to this philosophy.  If you are interested in
 seeing a number of different ways to invoke B<pod2usage> (although by no
 means exhaustive), please refer to L<"EXAMPLES">.
 
+=head2 Scripts
+
+The Pod::Usage distribution comes with a script pod2usage which offers
+a command line interface to the functionality of Pod::Usage. See
+L<pod2usage>.
+
+
 =head1 EXAMPLES
 
 Each of the following invocations of C<pod2usage()> will print just the
@@ -709,8 +728,9 @@ provide a means of printing their complete documentation to C<STDOUT>
 uses B<Pod::Usage> in combination with B<Getopt::Long> to do all of these
 things:
 
-    use Getopt::Long;
-    use Pod::Usage;
+    use strict;
+    use Getopt::Long qw(GetOptions);
+    use Pod::Usage qw(pod2usage);
 
     my $man = 0;
     my $help = 0;
@@ -723,6 +743,7 @@ things:
     ## If no arguments were given, then allow STDIN to be used only
     ## if it's not connected to a terminal (otherwise print usage)
     pod2usage("$0: No files given.")  if ((@ARGV == 0) && (-t STDIN));
+
     __END__
 
     =head1 NAME
@@ -739,7 +760,7 @@ things:
 
     =head1 OPTIONS
 
-    =over 8
+    =over 4
 
     =item B<-help>
 
